@@ -18,6 +18,7 @@ has memory_usage => (
     default => sub { Memory::Usage->new },
 );
 
+
 sub reset_memory_usage {
     my $self = shift;
 
@@ -51,6 +52,8 @@ before finalize => sub {
 1;
 
 
+
+
 __END__
 =pod
 
@@ -60,7 +63,7 @@ Catalyst::Plugin::MemoryUsage - Profile memory usage of requests
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 SYNOPSIS
 
@@ -102,6 +105,36 @@ log, which looks like this:
         1  47592 (     0)  40860 (     0)   3468 (     0)   1112 (     0)  37456 (     0) after Galuga::Controller::Root : _END
         1  47592 (     0)  40860 (     0)   3468 (     0)   1112 (     0)  37456 (     0) after Galuga::Controller::Root : _DISPATCH
 
+=head1 METHODS
+
+=head2 C<memory_usage()>
+
+Returns the L<Memory::Usage> object available to the context.
+
+To record more measure points for the memory profiling, use the C<record()>
+method of that object:
+
+    sub foo :Path {
+        my ( $self, $c) = @_;
+
+        ...
+
+        big_stuff();
+
+        $c->memory_usage->record( "done with big_stuff()" );
+
+        ...
+    }
+
+=head2 C<reset_memory_usage()>
+
+Discards the current C<Memory::Usage> object, along with its recorded data,
+and replaces it by a shiny new one.
+
+=head1 SEE ALSO
+
+L<Memory::Usage>
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@babyl.dyndns.org>
